@@ -13,7 +13,7 @@ class WalletCreateContract(Contract):
         (RUB, RUB),
         (USD, USD),
     )
-    currency_code = serializers.CharField(max_length=4, choices=CURRENCY_CODE_CHOICES)
+    currency_code = serializers.ChoiceField(choices=CURRENCY_CODE_CHOICES)
 
 
 class WalletReadContract(WalletCreateContract):
